API Reference
=============

.. toctree::
   :maxdepth: 2
   :caption: Contents


Common
------

.. automodule:: ptychodus.api.common
   :members:
   :undoc-members:
   :show-inheritance:

Diffraction
-----------

.. automodule:: ptychodus.api.diffraction
   :members:
   :undoc-members:
   :show-inheritance:

Fluorescence
------------

.. automodule:: ptychodus.api.fluorescence
   :members:
   :undoc-members:
   :show-inheritance:

Geometry
--------

.. automodule:: ptychodus.api.geometry
   :members:
   :undoc-members:
   :show-inheritance:

Input/Output (I/O)
------------------

.. automodule:: ptychodus.api.io
   :members:
   :undoc-members:
   :show-inheritance:

Object
------

.. automodule:: ptychodus.api.object
   :members:
   :undoc-members:
   :show-inheritance:

Observer
--------

.. automodule:: ptychodus.api.observer
   :members:
   :undoc-members:
   :show-inheritance:

Parametric
----------

.. automodule:: ptychodus.api.parametric
   :members:
   :undoc-members:
   :show-inheritance:

Plugins
-------

.. automodule:: ptychodus.api.plugins
   :members:
   :undoc-members:
   :show-inheritance:

Probe
-----

.. automodule:: ptychodus.api.probe
   :members:
   :undoc-members:
   :show-inheritance:

Probe Positions
---------------

.. automodule:: ptychodus.api.probe_positions
   :members:
   :undoc-members:
   :show-inheritance:

Product
-------

.. automodule:: ptychodus.api.product
   :members:
   :undoc-members:
   :show-inheritance:

Propagator
----------

.. automodule:: ptychodus.api.propagator
   :members:
   :undoc-members:
   :show-inheritance:

Reconstructor
-------------

.. automodule:: ptychodus.api.reconstructor
   :members:
   :undoc-members:
   :show-inheritance:

Settings
--------

.. automodule:: ptychodus.api.settings
   :members:
   :undoc-members:
   :show-inheritance:

Tree
----

.. automodule:: ptychodus.api.tree
   :members:
   :undoc-members:
   :show-inheritance:

Visualization
-------------

.. automodule:: ptychodus.api.visualization
   :members:
   :undoc-members:
   :show-inheritance:

Workflow
--------

.. automodule:: ptychodus.api.workflow
   :members:
   :undoc-members:
   :show-inheritance:
